@@ -33,6 +33,7 @@ from gvm.protocols.gmpv7.types import (
     InfoType,
     PermissionSubjectType,
     PortRangeType,
+    ReportFormatType,
     ScannerType,
     SeverityLevel,
     SnmpAuthAlgorithm,
@@ -49,6 +50,7 @@ from gvm.protocols.gmpv7.types import (
     get_info_type_from_string,
     get_permission_subject_type_from_string,
     get_port_range_type_from_string,
+    get_report_format_id_from_string,
     get_severity_level_from_string,
     get_scanner_type_from_string,
     get_snmp_auth_algorithm_from_string,
@@ -72,6 +74,7 @@ __all__ = [
     "InfoType",
     "PermissionSubjectType",
     "PortRangeType",
+    "ReportFormatType",
     "ScannerType",
     "SeverityLevel",
     "SnmpAuthAlgorithm",
@@ -92,6 +95,7 @@ __all__ = [
     "get_info_type_from_string",
     "get_permission_subject_type_from_string",
     "get_port_range_type_from_string",
+    "get_report_format_id_from_string",
     "get_scanner_type_from_string",
     "get_severity_level_from_string",
     "get_snmp_auth_algorithm_from_string",
