@@ -33,6 +33,12 @@ class Gmpv208CloneConfigTestCase(GmpCloneConfigTestCase, Gmpv208TestCase):
     pass
 
 
+class Gmpv208CloneReportFormatTestCase(
+    GmpCloneReportFormatTestCase, Gmpv208TestCase
+):
+    pass
+
+
 class Gmpv208CloneCredentialTestCase(
     GmpCloneCredentialTestCase, Gmpv208TestCase
 ):
@@ -440,6 +446,12 @@ class Gmpv208ImportConfigTestCase(GmpImportConfigTestCase, Gmpv208TestCase):
     pass
 
 
+class Gmpv208ImportReportFormatTestCase(
+    GmpImportReportFormatTestCase, Gmpv208TestCase
+):
+    pass
+
+
 class Gmpv208ImportReportTestCase(GmpImportReportTestCase, Gmpv208TestCase):
     pass
 
@@ -502,12 +514,6 @@ class Gmpv208ModifyPortListTestCase(GmpModifyPortListTestCase, Gmpv208TestCase):
     pass
 
 
-class Gmpv208ModifyReportFormatTestCase(
-    GmpModifyReportFormatTestCase, Gmpv208TestCase
-):
-    pass
-
-
 class Gmpv208ModifyRoleTestCase(GmpModifyRoleTestCase, Gmpv208TestCase):
     pass
 
